aboutsummaryrefslogtreecommitdiff
path: root/gdb/sh3-rom.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/sh3-rom.c')
-rw-r--r--gdb/sh3-rom.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/gdb/sh3-rom.c b/gdb/sh3-rom.c
index a2e21c1..cec9fba 100644
--- a/gdb/sh3-rom.c
+++ b/gdb/sh3-rom.c
@@ -1,4 +1,4 @@
/* Remote target glue for the Hitachi SH-3 ROM monitor.
Copyright 1995, 1996, 1997, 1998, 1999, 2000, 2001
Free Software Foundation, Inc.
@@ -365,11 +365,11 @@ _initialize_sh3_rom (void)
init_monitor_ops (&sh3_ops);
sh3_ops.to_shortname = "sh3";
- sh3_ops.to_longname = "Hitachi SH-3 rom monitor";
+ sh3_ops.to_longname = "Renesas SH-3 rom monitor";
sh3_ops.to_doc =
/* We can download through the parallel port too. */
- "Debug on a Hitachi eval board running the SH-3E rom monitor.\n"
+ "Debug on a Renesas eval board running the SH-3E rom monitor.\n"
"Specify the serial device it is connected to.\n"
"If you want to use the parallel port to download to it, specify that\n"
"as an additional second argument.";
@@ -384,11 +384,11 @@ _initialize_sh3_rom (void)
init_monitor_ops (&sh3e_ops);
sh3e_ops.to_shortname = "sh3e";
- sh3e_ops.to_longname = "Hitachi SH-3E rom monitor";
+ sh3e_ops.to_longname = "Renesas SH-3E rom monitor";
sh3e_ops.to_doc =
/* We can download through the parallel port too. */
- "Debug on a Hitachi eval board running the SH-3E rom monitor.\n"
+ "Debug on a Renesas eval board running the SH-3E rom monitor.\n"
"Specify the serial device it is connected to.\n"
"If you want to use the parallel port to download to it, specify that\n"
"as an additional second argument.";
@@ -1,4 +1,4 @@
-/* Remote target glue for the Hitachi SH-3 ROM monitor.
+/* Remote target glue for the Renesas SH-3 ROM monitor.
Copyright 1995, 1996, 1997, 1998, 1999, 2000, 2001
Free Software Foundation, Inc.